# coding: utf-8

"""
    Arthur Scope

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from arthur_client.api_bindings.models.resource_list_policy_assignment import ResourceListPolicyAssignment

class TestResourceListPolicyAssignment(unittest.TestCase):
    """ResourceListPolicyAssignment unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ResourceListPolicyAssignment:
        """Test ResourceListPolicyAssignment
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ResourceListPolicyAssignment`
        """
        model = ResourceListPolicyAssignment()
        if include_optional:
            return ResourceListPolicyAssignment(
                records = [
                    arthur_client.api_bindings.models.policy_assignment.PolicyAssignment(
                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        id = '', 
                        policy = arthur_client.api_bindings.models.policy_summary.PolicySummary(
                            id = '', 
                            name = '', 
                            description = '', ), 
                        model = arthur_client.api_bindings.models.model_summary.ModelSummary(
                            id = '', 
                            name = '', 
                            project_id = '', ), 
                        applied_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        applied_by_user_id = '', 
                        enforcement_starts_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        compliance_status = arthur_client.api_bindings.models.compliance_status_detail.ComplianceStatusDetail(
                            status = 'PENDING', 
                            alert_rules = arthur_client.api_bindings.models.compliance_alert_rule_results.ComplianceAlertRuleResults(
                                compliant = [
                                    arthur_client.api_bindings.models.compliant_alert_rule_status.CompliantAlertRuleStatus(
                                        id = '', 
                                        name = '', )
                                    ], 
                                non_compliant = [
                                    arthur_client.api_bindings.models.non_compliant_alert_rule_status.NonCompliantAlertRuleStatus(
                                        id = '', 
                                        name = '', 
                                        alert = arthur_client.api_bindings.models.compliance_alert_summary.ComplianceAlertSummary(
                                            description = '', 
                                            id = '', ), )
                                    ], ), 
                            attestation_rules = arthur_client.api_bindings.models.compliance_attestation_rule_results.ComplianceAttestationRuleResults(), ), 
                        compliance_job = arthur_client.api_bindings.models.job.Job(
                            id = '', 
                            kind = 'metrics_calculation', 
                            job_spec = null, 
                            state = 'queued', 
                            project_id = '', 
                            data_plane_id = '', 
                            queued_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            ready_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            started_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            finished_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            duration_sec = 56, 
                            error_count = 56, 
                            trigger_type = 'user', 
                            triggered_by_user = arthur_client.api_bindings.models.user.User(
                                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                organization_id = '', 
                                id = '', 
                                first_name = '', 
                                last_name = '', 
                                email = '', 
                                picture = '', 
                                user_type = 'user', 
                                data_plane_id = '', 
                                client_id = '', 
                                organization_name = '', ), 
                            schedule_id = '', 
                            attempts = 56, 
                            max_attempts = 56, 
                            nonce = '', 
                            memory_requirements_mb = 56, 
                            job_priority = 100, ), 
                        last_violation_notified_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                    ],
                pagination = arthur_client.api_bindings.models.pagination.Pagination(
                    page = 56, 
                    page_size = 56, 
                    total_pages = 56, 
                    total_records = 56, )
            )
        else:
            return ResourceListPolicyAssignment(
                records = [
                    arthur_client.api_bindings.models.policy_assignment.PolicyAssignment(
                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        id = '', 
                        policy = arthur_client.api_bindings.models.policy_summary.PolicySummary(
                            id = '', 
                            name = '', 
                            description = '', ), 
                        model = arthur_client.api_bindings.models.model_summary.ModelSummary(
                            id = '', 
                            name = '', 
                            project_id = '', ), 
                        applied_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        applied_by_user_id = '', 
                        enforcement_starts_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        compliance_status = arthur_client.api_bindings.models.compliance_status_detail.ComplianceStatusDetail(
                            status = 'PENDING', 
                            alert_rules = arthur_client.api_bindings.models.compliance_alert_rule_results.ComplianceAlertRuleResults(
                                compliant = [
                                    arthur_client.api_bindings.models.compliant_alert_rule_status.CompliantAlertRuleStatus(
                                        id = '', 
                                        name = '', )
                                    ], 
                                non_compliant = [
                                    arthur_client.api_bindings.models.non_compliant_alert_rule_status.NonCompliantAlertRuleStatus(
                                        id = '', 
                                        name = '', 
                                        alert = arthur_client.api_bindings.models.compliance_alert_summary.ComplianceAlertSummary(
                                            description = '', 
                                            id = '', ), )
                                    ], ), 
                            attestation_rules = arthur_client.api_bindings.models.compliance_attestation_rule_results.ComplianceAttestationRuleResults(), ), 
                        compliance_job = arthur_client.api_bindings.models.job.Job(
                            id = '', 
                            kind = 'metrics_calculation', 
                            job_spec = null, 
                            state = 'queued', 
                            project_id = '', 
                            data_plane_id = '', 
                            queued_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            ready_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            started_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            finished_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            duration_sec = 56, 
                            error_count = 56, 
                            trigger_type = 'user', 
                            triggered_by_user = arthur_client.api_bindings.models.user.User(
                                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                organization_id = '', 
                                id = '', 
                                first_name = '', 
                                last_name = '', 
                                email = '', 
                                picture = '', 
                                user_type = 'user', 
                                data_plane_id = '', 
                                client_id = '', 
                                organization_name = '', ), 
                            schedule_id = '', 
                            attempts = 56, 
                            max_attempts = 56, 
                            nonce = '', 
                            memory_requirements_mb = 56, 
                            job_priority = 100, ), 
                        last_violation_notified_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                    ],
                pagination = arthur_client.api_bindings.models.pagination.Pagination(
                    page = 56, 
                    page_size = 56, 
                    total_pages = 56, 
                    total_records = 56, ),
        )
        """

    def testResourceListPolicyAssignment(self):
        """Test ResourceListPolicyAssignment"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
